aboutsummaryrefslogtreecommitdiff
path: root/mod/file
diff options
context:
space:
mode:
authorcash <cash.costello@gmail.com>2011-10-03 21:56:14 -0400
committercash <cash.costello@gmail.com>2011-10-03 21:56:14 -0400
commit9d5c00c78c0666a31485d870a1e657d4557b23c4 (patch)
tree936fbeaf02a15e3559612ea1cb0c416f41597a8d /mod/file
parentfa04d6615760a014f7557f2d28ff864eebce8551 (diff)
downloadelgg-9d5c00c78c0666a31485d870a1e657d4557b23c4.tar.gz
elgg-9d5c00c78c0666a31485d870a1e657d4557b23c4.tar.bz2
using better insert class
Diffstat (limited to 'mod/file')
-rw-r--r--mod/file/views/default/icon/object/file.php15
1 files changed, 10 insertions, 5 deletions
diff --git a/mod/file/views/default/icon/object/file.php b/mod/file/views/default/icon/object/file.php
index 6357d418f..7feba7af3 100644
--- a/mod/file/views/default/icon/object/file.php
+++ b/mod/file/views/default/icon/object/file.php
@@ -2,9 +2,10 @@
/**
* File icon view
*
* @uses $vars['entity'] The entity the icon represents - uses getIconURL() method
* @uses $vars['size'] topbar, tiny, small, medium (default), large, master
* @uses $vars['href'] Optional override for link
*/
$entity = $vars['entity'];
@@ -32,10 +33,14 @@ $img_src = elgg_format_url($img_src);
$img = "<img $class src=\"$img_src\" alt=\"$title\" />";
if ($url) {
- echo elgg_view('output/url', array(
+ $params = array(
'href' => $url,
'text' => $img,
- ));
+ );
+ if (isset($vars['link_class'])) {
+ $params['class'] = $vars['link_class'];
+ }
+ echo elgg_view('output/url', $params);
} else {
echo $img;
}
@@ -2,9 +2,10 @@
* File icon view
*
- * @uses $vars['entity'] The entity the icon represents - uses getIconURL() method
- * @uses $vars['size'] topbar, tiny, small, medium (default), large, master
- * @uses $vars['href'] Optional override for link
+ * @uses $vars['entity'] The entity the icon represents - uses getIconURL() method
+ * @uses $vars['size'] topbar, tiny, small, medium (default), large, master
+ * @uses $vars['href'] Optional override for link
+ * @uses $vars['link_class'] Optional CSS class added to img
*/
$entity = $vars['entity'];